/**
  *  \file int/predict.h
  *  \brief Interpreter: Auto Task Predictions
  *
  *  (c) 2001-2022 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_INT_PREDICT_H
#define PCC_V2_INT_PREDICT_H

#include "cpluslib/string.h"
#include "cpluslib/types.h"

class IntAutoTaskEditor;
class IntArgBlock;

/** Auto Task Prediction. An IntAutoTaskPredictor operates on the
    format provided by an IntAutoTaskEditor to predict future states
    of the object. A derived class provides an implementation of the
    predictInstruction method which computes the actual effects; this
    class contains control and parsing. */
class IntAutoTaskPredictor {
 public:
    IntAutoTaskPredictor();
    virtual ~IntAutoTaskPredictor();

    /** Predict one instruction.
        \param name Name of command (e.g. "MOVETO")
        \param args Arguments of command
        \retval true successful interpretation, continue
        \retval false error, stop */
    virtual bool predictInstruction(const string_t& name, IntArgBlock& args) = 0;

    void predictTask(const IntAutoTaskEditor& editor, uint32_t endPC = ~uint32_t(0));
    void predictStatement(const IntAutoTaskEditor& editor, uint32_t pc);
};

#endif
