/**
  *  \file ui/widgets/abstractcheckbox.cc
  *  \brief UIAbstractCheckbox base class
  *
  *  (c) 2001-2022 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "ui/widgets/abstractcheckbox.h"
#include "gfx/gfxcontext.h"
#include "ui/skin.h"
#include "ui/uiglobal.h"

UIAbstractCheckbox::UIAbstractCheckbox(int id, string_t name, UIKey key)
    : UIAbstractButton(id, key), name(name)
{
    sig_fired.add(this, &UIAbstractCheckbox::click);
}

UIAbstractCheckbox::~UIAbstractCheckbox()
{ }

void
UIAbstractCheckbox::drawContent(GfxCanvas& can)
{
    if (Ptr<GfxPixmap> pix = getPixmap())
        pix->blit(can, extent.x + 12 - pix->getWidth()/2, extent.y + 12 - pix->getHeight()/2);

    GfxContext ctx;
    ctx.useCanvas(can);
    ctx.useColorScheme(getSkin());
    if (name.length()) {
        if (hasState(st_Disabled))
            ctx.setColor(UIColor::tc_Faded);
        else
            ctx.setColor(UIColor::tc_Static);
        ctx.useFont(*fonts[FONT_TITLE]);
        outTextF(ctx, extent.x + 24, extent.y + 2, extent.w - 24, name);
    }

    // FIXME: use drawBackground to draw the non-rectangle!
    if (getFocusState() != NoFocus)
        ctx.setColor(UIColor::tc_Static);
    else
        ctx.setColor(UIColor::tc_Background);
    drawRectangle(ctx, GfxRect(extent.x, extent.y, 24, 24));

    can.update(getExtent());
}

void
UIAbstractCheckbox::getLayoutInfo(LayoutInfo& info)
{
    info.flags = li_FlexibleH;
    info.min_size = GfxPoint(24, 24);
    if (name.length())
        info.min_size.x += fonts[FONT_TITLE]->getTextWidth(name) + 2;
    info.pref_size = info.min_size;
}

void
UIAbstractCheckbox::onStateChange(int state, bool enabled)
{
    UIAbstractButton::onStateChange(state, enabled);
    if (state & st_Focused)
        drawWidget(false);
}

bool
UIAbstractCheckbox::handleEvent(const UIEvent& e, bool second_pass)
{
    if (hasState(st_Focused) && e.type == ev_Key && e.key.code == ' ') {
        setSelectedWidget();
        click(0);
        return true;
    }
    return UIAbstractButton::handleEvent(e, second_pass);
}

